pub struct ImageProgressLayer {
pub id: String,
pub phase: i32,
pub indication: Option<ImageProgressIndication>,
}Fields
id: Stringphase: i32indication: Option<ImageProgressIndication>Implementations
Sourceimpl ImageProgressLayer
impl ImageProgressLayer
Sourcepub fn phase(&self) -> ImageProgressLayerPhase
pub fn phase(&self) -> ImageProgressLayerPhase
Returns the enum value of phase, or the default if the field is set to an invalid enum value.
Sourcepub fn set_phase(&mut self, value: ImageProgressLayerPhase)
pub fn set_phase(&mut self, value: ImageProgressLayerPhase)
Sets phase to the provided enum value.